## dbt-spark 1.10.1 - February 11, 2026

### Features

- Add support for py3.13 ([#1475](https://github.com/dbt-labs/dbt-adapters/issues/1475))

### Dependencies

- Add support for Spark v4.x ([#1537](https://github.com/dbt-labs/dbt-adapters/pull/1537))

### Contributors
- [@thmshmm](https://github.com/thmshmm) ([#1537](https://github.com/dbt-labs/dbt-adapters/pull/1537))
